@@ -31,7 +31,10 @@ import { AppState } from '../../../store';
 import * as DevfileRegistriesStore from '../../../store/DevfileRegistries';
 import { SampleCard } from './SampleCard';
 import { AlertItem } from '../../../services/helpers/types';
-import { selectMetadataFiltered } from '../../../store/DevfileRegistries/selectors';
+import {
+  EMPTY_WORKSPACE_TAG,
+  selectMetadataFiltered,
+} from '../../../store/DevfileRegistries/selectors';
 import { selectWorkspacesSettings } from '../../../store/Workspaces/Settings/selectors';
 import * as FactoryResolverStore from '../../../store/FactoryResolver';
 import { isDevworkspacesEnabled } from '../../../services/helpers/devworkspace';
@@ -60,9 +63,19 @@ type State = {
 };
 
 export const VISIBLE_TAGS = ['Community', 'Tech-Preview'];
-const EXCLUDED_TARGET_EDITOR_NAMES = ['dirigible', 'jupyter', 'eclipseide', 'code-server'];
+
+const EXCLUDED_TARGET_EDITOR_NAMES = ['che-idea'];
 
 export class SamplesListGallery extends React.PureComponent<Props, State> {
+  private static sortByName(a: TargetEditor, b: TargetEditor): number {
+    if (a.name < b.name) {
+      return -1;
+    }
+    if (a.name > b.name) {
+      return 1;
+    }
+    return 0;
+  }
   private static sortByVisibleTag(a: che.DevfileMetaData, b: che.DevfileMetaData): number {
     const getVisibleTag = (metadata: che.DevfileMetaData) =>
       metadata.tags.filter(tag => VISIBLE_TAGS.includes(tag))[0];
@@ -79,11 +92,11 @@ export class SamplesListGallery extends React.PureComponent<Props, State> {
     }
     return 0;
   }
-  private static sortByName(a: TargetEditor, b: TargetEditor): number {
-    if (a.name < b.name) {
+  private static sortByEmptyWorkspaceTag(a: che.DevfileMetaData, b: che.DevfileMetaData): number {
+    if (a.tags.includes(EMPTY_WORKSPACE_TAG) > b.tags.includes(EMPTY_WORKSPACE_TAG)) {
       return -1;
     }
-    if (a.name > b.name) {
+    if (a.tags.includes(EMPTY_WORKSPACE_TAG) < b.tags.includes(EMPTY_WORKSPACE_TAG)) {
       return 1;
     }
     return 0;
@@ -204,6 +217,7 @@ export class SamplesListGallery extends React.PureComponent<Props, State> {
     return metadata
       .sort(SamplesListGallery.sortByDisplayName)
       .sort(SamplesListGallery.sortByVisibleTag)
+      .sort(SamplesListGallery.sortByEmptyWorkspaceTag)
       .map(meta => (
         <SampleCard
           key={meta.links.self}
