@@ -24,7 +24,6 @@ import * as InfrastructureNamespacesStore from '../../store/InfrastructureNamesp
 import * as PluginsStore from '../../store/Plugins/chePlugins';
 import * as DwPluginsStore from '../../store/Plugins/devWorkspacePlugins';
 import * as UserProfileStore from '../../store/UserProfile';
-import * as UserStore from '../../store/User';
 import * as WorkspacesStore from '../../store/Workspaces';
 import * as DevWorkspacesStore from '../../store/Workspaces/devWorkspaces';
 import * as WorkspacesSettingsStore from '../../store/Workspaces/Settings';
@@ -41,6 +40,8 @@ import { AlertVariant } from '@patternfly/react-core';
 import { buildDetailsLocation, buildIdeLoaderLocation } from '../helpers/location';
 import { Workspace } from '../workspace-adapter';
 import { WorkspaceRunningError, WorkspaceStoppedDetector } from './workspaceStoppedDetector';
+import { selectOpenVSXUrl } from '../../store/ServerConfig/selectors';
+import { selectEmptyWorkspaceUrl } from '../../store/DevfileRegistries/selectors';
 
 /**
  * This class executes a few initial instructions
@@ -82,15 +83,16 @@ export default class Bootstrap {
     ]);
 
     const results = await Promise.allSettled([
-      this.fetchCurrentUser(),
       this.fetchUserProfile(),
       this.fetchPlugins().then(() => this.fetchDevfileSchema()),
       this.fetchDwPlugins(),
       this.fetchDefaultDwPlugins(),
-      this.fetchRegistriesMetadata(),
-      this.watchNamespaces(),
+      this.fetchRegistriesMetadata().then(() => this.fetchEmptyWorkspace()),
       this.updateDevWorkspaceTemplates(),
-      this.fetchWorkspaces().then(() => this.checkWorkspaceStopped()),
+      this.fetchWorkspaces().then(() => {
+        this.checkWorkspaceStopped();
+        return this.watchNamespaces();
+      }),
       this.fetchClusterInfo(),
       this.fetchClusterConfig(),
     ]);
@@ -164,11 +166,6 @@ export default class Bootstrap {
     return await this.devWorkspaceClient.subscribeToNamespace({ namespace, callbacks });
   }
 
-  private async fetchCurrentUser(): Promise<void> {
-    const { requestUser } = UserStore.actionCreators;
-    await requestUser()(this.store.dispatch, this.store.getState, undefined);
-  }
-
   private async fetchWorkspaces(): Promise<void> {
     const { requestWorkspaces } = WorkspacesStore.actionCreators;
     await requestWorkspaces()(this.store.dispatch, this.store.getState, undefined);
@@ -216,14 +213,16 @@ export default class Bootstrap {
       selectDwEditorsPluginsList(state.dwPlugins.defaultEditorName)(state).forEach(dwEditor => {
         pluginsByUrl[dwEditor.url] = dwEditor.devfile;
       });
+      const openVSXUrl = selectOpenVSXUrl(state);
       const settings = this.store.getState().workspacesSettings.settings;
       const pluginRegistryUrl = settings['cheWorkspacePluginRegistryUrl'];
       const pluginRegistryInternalUrl = settings['cheWorkspacePluginRegistryInternalUrl'];
       const updates = await this.devWorkspaceClient.checkForTemplatesUpdate(
         defaultNamespace,
         pluginsByUrl,
-        pluginRegistryUrl || '',
-        pluginRegistryInternalUrl || '',
+        pluginRegistryUrl,
+        pluginRegistryInternalUrl,
+        openVSXUrl,
       );
       if (Object.keys(updates).length > 0) {
         await this.devWorkspaceClient.updateTemplates(defaultNamespace, updates);
@@ -284,17 +283,33 @@ export default class Bootstrap {
     );
   }
 
+  private async fetchEmptyWorkspace(): Promise<void> {
+    const { requestDevfile } = DevfileRegistriesStore.actionCreators;
+    const state = this.store.getState();
+    const emptyWorkspaceUrl = selectEmptyWorkspaceUrl(state);
+    if (emptyWorkspaceUrl) {
+      await requestDevfile(emptyWorkspaceUrl)(this.store.dispatch, this.store.getState, undefined);
+    }
+  }
+
   private async fetchDevfileSchema(): Promise<void> {
     const { requestJsonSchema } = DevfileRegistriesStore.actionCreators;
     return requestJsonSchema()(this.store.dispatch, this.store.getState, undefined);
   }
 
   private async fetchUserProfile(): Promise<void> {
+    const defaultKubernetesNamespace = selectDefaultNamespace(this.store.getState());
+    const defaultNamespace = defaultKubernetesNamespace.name;
+
     const { requestUserProfile } = UserProfileStore.actionCreators;
-    return requestUserProfile()(this.store.dispatch, this.store.getState, undefined);
+    return requestUserProfile(defaultNamespace)(
+      this.store.dispatch,
+      this.store.getState,
+      undefined,
+    );
   }
 
-  private checkWorkspaceStopped() {
+  private checkWorkspaceStopped(): void {
     let stoppedWorkspace: Workspace | undefined = undefined;
 
     try {
