@@ -10,10 +10,9 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import axios from 'axios';
-import common from '@eclipse-che/common';
-import { prefix } from './const';
 import { api } from '@eclipse-che/common';
+import axios from 'axios';
+import { prefix } from './const';
 
 /**
  * Returns an array of default plug-ins per editor
@@ -24,10 +23,6 @@ import { api } from '@eclipse-che/common';
  */
 export async function getServerConfig(): Promise<api.IServerConfig> {
   const url = `${prefix}/server-config`;
-  try {
-    const response = await axios.get(url);
-    return response.data ? response.data : [];
-  } catch (e) {
-    throw `Failed to fetch default plugins. ${common.helpers.errors.getMessage(e)}`;
-  }
+  const response = await axios.get(url);
+  return response.data ? response.data : [];
 }
