@@ -10,42 +10,47 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import { inject, injectable, multiInject } from 'inversify';
-import { isWebTerminal } from '../../helpers/devworkspace';
-import { WorkspaceClient } from '../index';
-import devfileApi, { isDevWorkspace } from '../../devfileApi';
-import { api } from '@eclipse-che/common';
-import {
-  devfileToDevWorkspace,
-  devWorkspaceApiGroup,
-  devWorkspaceSingularSubresource,
-  devWorkspaceVersion,
-} from './converters';
-import { AlertItem, DevWorkspaceStatus, isDevWorkspaceStatus } from '../../helpers/types';
-import { delay } from '../../helpers/delay';
-import * as DwApi from '../../dashboard-backend-client/devWorkspaceApi';
-import * as DwtApi from '../../dashboard-backend-client/devWorkspaceTemplateApi';
-import { WebsocketClient, SubscribeMessage } from '../../dashboard-backend-client/websocketClient';
-import { EventEmitter } from 'events';
-import { AppAlerts } from '../../alerts/appAlerts';
-import { AlertVariant } from '@patternfly/react-core';
-import { WorkspaceAdapter } from '../../workspace-adapter';
-import { safeLoad } from 'js-yaml';
-import {
-  DEVWORKSPACE_CHE_EDITOR,
-  DEVWORKSPACE_UPDATING_TIMESTAMP_ANNOTATION,
-} from '../../devfileApi/devWorkspace/metadata';
-import { AxiosInstance } from 'axios';
 import {
   V1alpha2DevWorkspaceSpecTemplateComponents,
   V1alpha2DevWorkspaceTemplateSpec,
   V1alpha2DevWorkspaceTemplateSpecComponents,
   V220DevfileComponentsItemsContainer,
 } from '@devfile/api';
-import { isEqual } from 'lodash';
-import { fetchData } from '../../registry/fetchData';
-import { DevWorkspaceDefaultPluginsHandler } from './DevWorkspaceDefaultPluginsHandler';
+import { api } from '@eclipse-che/common';
+import { AlertVariant } from '@patternfly/react-core';
+import { AxiosInstance } from 'axios';
 import { WorkspacesDefaultPlugins } from 'dashboard-frontend/src/store/Plugins/devWorkspacePlugins';
+import { EventEmitter } from 'events';
+import { inject, injectable, multiInject } from 'inversify';
+import { safeLoad } from 'js-yaml';
+import { cloneDeep, isEqual } from 'lodash';
+import { AppAlerts } from '../../alerts/appAlerts';
+import * as DwApi from '../../dashboard-backend-client/devWorkspaceApi';
+import * as DwtApi from '../../dashboard-backend-client/devWorkspaceTemplateApi';
+import { SubscribeMessage, WebsocketClient } from '../../dashboard-backend-client/websocketClient';
+import devfileApi, { isDevWorkspace } from '../../devfileApi';
+import {
+  DEVWORKSPACE_CHE_EDITOR,
+  DEVWORKSPACE_UPDATING_TIMESTAMP_ANNOTATION,
+} from '../../devfileApi/devWorkspace/metadata';
+import {
+  DEVWORKSPACE_CONFIG_ATTR,
+  DEVWORKSPACE_CONTAINER_BUILD_ATTR,
+  DEVWORKSPACE_STORAGE_TYPE_ATTR,
+} from '../../devfileApi/devWorkspace/spec/template';
+import { delay } from '../../helpers/delay';
+import { isWebTerminal } from '../../helpers/devworkspace';
+import { AlertItem, DevWorkspaceStatus, isDevWorkspaceStatus } from '../../helpers/types';
+import { fetchData } from '../../registry/fetchData';
+import { WorkspaceAdapter } from '../../workspace-adapter';
+import { WorkspaceClient } from '../index';
+import {
+  devfileToDevWorkspace,
+  devWorkspaceApiGroup,
+  devWorkspaceSingularSubresource,
+  devWorkspaceVersion,
+} from './converters';
+import { DevWorkspaceDefaultPluginsHandler } from './DevWorkspaceDefaultPluginsHandler';
 
 export interface IStatusUpdate {
   status: DevWorkspaceStatus;
@@ -55,6 +60,7 @@ export interface IStatusUpdate {
   mainUrl?: string;
   namespace?: string;
   workspaceId?: string;
+  started: boolean;
 }
 
 export type Subscriber = {
@@ -111,10 +117,6 @@ export const DEVWORKSPACE_NEXT_START_ANNOTATION = 'che.eclipse.org/next-start-cf
 
 export const DEVWORKSPACE_DEBUG_START_ANNOTATION = 'controller.devfile.io/debug-start';
 
-export const DEVWORKSPACE_CONFIG_ANNOTATION = 'controller.devfile.io/devworkspace-config';
-
-export const DEVWORKSPACE_STORAGE_TYPE = 'controller.devfile.io/storage-type';
-
 export const DEVWORKSPACE_DEVFILE_SOURCE = 'che.eclipse.org/devfile-source';
 
 export const DEVWORKSPACE_METADATA_ANNOTATION = 'dw.metadata.annotations';
@@ -142,6 +144,7 @@ export class DevWorkspaceClient extends WorkspaceClient {
   private readonly maxStatusAttempts: number;
   private readonly pluginRegistryUrlEnvName: string;
   private readonly pluginRegistryInternalUrlEnvName: string;
+  private readonly openVSXUrlEnvName: string;
   private readonly dashboardUrlEnvName: string;
   private readonly websocketClient: WebsocketClient;
   private webSocketEventEmitter: EventEmitter;
@@ -161,6 +164,7 @@ export class DevWorkspaceClient extends WorkspaceClient {
     this.maxStatusAttempts = 10;
     this.pluginRegistryUrlEnvName = 'CHE_PLUGIN_REGISTRY_URL';
     this.pluginRegistryInternalUrlEnvName = 'CHE_PLUGIN_REGISTRY_INTERNAL_URL';
+    this.openVSXUrlEnvName = 'OPENVSX_REGISTRY_URL';
     this.dashboardUrlEnvName = 'CHE_DASHBOARD_URL';
     this.webSocketEventEmitter = new EventEmitter();
     this.webSocketEventName = 'websocketClose';
@@ -259,8 +263,9 @@ export class DevWorkspaceClient extends WorkspaceClient {
     devworkspace: devfileApi.DevWorkspace,
     devworkspaceTemplate: devfileApi.DevWorkspaceTemplate,
     editorId: string | undefined,
-    pluginRegistryUrl = '',
-    pluginRegistryInternalUrl = '',
+    pluginRegistryUrl: string | undefined,
+    pluginRegistryInternalUrl: string | undefined,
+    openVSXUrl: string | undefined,
   ): Promise<any> {
     // create DW
     devworkspace.spec.routingClass = 'che';
@@ -281,7 +286,12 @@ export class DevWorkspaceClient extends WorkspaceClient {
     devworkspace.spec.started = false;
     const createdWorkspace = await DwApi.createWorkspace(devworkspace);
 
-    this.addEnvVarsToContainers(components, pluginRegistryUrl, pluginRegistryInternalUrl);
+    this.addEnvVarsToContainers(
+      components,
+      pluginRegistryUrl,
+      pluginRegistryInternalUrl,
+      openVSXUrl,
+    );
 
     // create DWT
     devworkspaceTemplate.metadata.namespace = defaultNamespace;
@@ -298,6 +308,7 @@ export class DevWorkspaceClient extends WorkspaceClient {
       devworkspaceTemplate.spec?.components,
       pluginRegistryUrl,
       pluginRegistryInternalUrl,
+      openVSXUrl,
     );
 
     await DwtApi.createTemplate(devworkspaceTemplate);
@@ -323,6 +334,7 @@ export class DevWorkspaceClient extends WorkspaceClient {
     dwEditorsPlugins: { devfile: devfileApi.Devfile; url: string }[],
     pluginRegistryUrl: string | undefined,
     pluginRegistryInternalUrl: string | undefined,
+    openVSXUrl: string | undefined,
     editorId: string | undefined,
     optionalFilesContent: { [fileName: string]: string },
   ): Promise<devfileApi.DevWorkspace> {
@@ -495,8 +507,9 @@ export class DevWorkspaceClient extends WorkspaceClient {
         ];
         this.addEnvVarsToContainers(
           template.spec?.components,
-          pluginRegistryUrl || '',
-          pluginRegistryInternalUrl || '',
+          pluginRegistryUrl,
+          pluginRegistryInternalUrl,
+          openVSXUrl,
         );
 
         const pluginDWT = await DwtApi.createTemplate(<devfileApi.DevWorkspaceTemplate>template);
@@ -506,8 +519,9 @@ export class DevWorkspaceClient extends WorkspaceClient {
 
     this.addEnvVarsToContainers(
       createdWorkspace.spec.template.components,
-      pluginRegistryUrl || '',
-      pluginRegistryInternalUrl || '',
+      pluginRegistryUrl,
+      pluginRegistryInternalUrl,
+      openVSXUrl,
     );
     createdWorkspace.spec.started = false;
     const patch = [
@@ -530,13 +544,16 @@ export class DevWorkspaceClient extends WorkspaceClient {
       | V1alpha2DevWorkspaceSpecTemplateComponents[]
       | V1alpha2DevWorkspaceTemplateSpecComponents[]
       | undefined,
-    pluginRegistryUrl: string,
-    pluginRegistryInternalUrl: string,
+    pluginRegistryUrl: string | undefined,
+    pluginRegistryInternalUrl: string | undefined,
+    openVSXUrl: string | undefined,
   ): void {
     if (components === undefined) {
       return;
     }
 
+    const dashboardUrl = window.location.origin;
+
     for (const component of components) {
       const container = component.container;
       if (container === undefined) {
@@ -546,22 +563,31 @@ export class DevWorkspaceClient extends WorkspaceClient {
         env =>
           env.name !== this.dashboardUrlEnvName &&
           env.name !== this.pluginRegistryUrlEnvName &&
-          env.name !== this.pluginRegistryInternalUrlEnvName,
+          env.name !== this.pluginRegistryInternalUrlEnvName &&
+          env.name !== this.openVSXUrlEnvName,
       );
-      envs.push(
-        {
-          name: this.dashboardUrlEnvName,
-          value: window.location.origin,
-        },
-        {
+      envs.push({
+        name: this.dashboardUrlEnvName,
+        value: dashboardUrl,
+      });
+      if (pluginRegistryUrl !== undefined) {
+        envs.push({
           name: this.pluginRegistryUrlEnvName,
           value: pluginRegistryUrl,
-        },
-        {
+        });
+      }
+      if (pluginRegistryInternalUrl !== undefined) {
+        envs.push({
           name: this.pluginRegistryInternalUrlEnvName,
           value: pluginRegistryInternalUrl,
-        },
-      );
+        });
+      }
+      if (openVSXUrl !== undefined) {
+        envs.push({
+          name: this.openVSXUrlEnvName,
+          value: openVSXUrl,
+        });
+      }
       container.env = envs;
     }
   }
@@ -725,26 +751,21 @@ export class DevWorkspaceClient extends WorkspaceClient {
     return workspace.metadata.annotations?.[DEVWORKSPACE_DEBUG_START_ANNOTATION] === 'true';
   }
 
-  async updateConfigData(
+  async managePvcStrategy(
     workspace: devfileApi.DevWorkspace,
     config: api.IServerConfig,
-  ): Promise<void> {
+  ): Promise<devfileApi.DevWorkspace> {
     const patch: api.IPatch[] = [];
-    if (workspace.spec.started) {
-      return;
-    }
     const cheNamespace = config.cheNamespace;
+    let attributes = workspace.spec.template.attributes;
     if (cheNamespace) {
       const devworkspaceConfig = { name: 'devworkspace-config', namespace: cheNamespace };
       const devworkspaceConfigPath = `/spec/template/attributes/${this.escape(
-        DEVWORKSPACE_CONFIG_ANNOTATION,
+        DEVWORKSPACE_CONFIG_ATTR,
       )}`;
-      if (workspace.spec.template.attributes) {
-        if (workspace.spec.template.attributes[DEVWORKSPACE_CONFIG_ANNOTATION]) {
-          if (
-            workspace.spec.template.attributes[DEVWORKSPACE_CONFIG_ANNOTATION] !==
-            devworkspaceConfig
-          ) {
+      if (attributes) {
+        if (attributes[DEVWORKSPACE_CONFIG_ATTR]) {
+          if (attributes[DEVWORKSPACE_CONFIG_ATTR] !== devworkspaceConfig) {
             patch.push({ op: 'replace', path: devworkspaceConfigPath, value: devworkspaceConfig });
           }
         } else {
@@ -754,59 +775,122 @@ export class DevWorkspaceClient extends WorkspaceClient {
         patch.push({
           op: 'add',
           path: '/spec/template/attributes',
-          value: { 'controller.devfile.io/devworkspace-config': devworkspaceConfig },
+          value: { [DEVWORKSPACE_CONFIG_ATTR]: devworkspaceConfig },
         });
+        attributes = {};
       }
     }
 
     const currentPvcStrategy = config.defaults.pvcStrategy;
     if (currentPvcStrategy) {
       const devworkspaceStorageTypePath = `/spec/template/attributes/${this.escape(
-        DEVWORKSPACE_STORAGE_TYPE,
+        DEVWORKSPACE_STORAGE_TYPE_ATTR,
       )}`;
 
-      if (workspace.spec.template.attributes) {
-        if (!workspace.spec.template.attributes[DEVWORKSPACE_STORAGE_TYPE]) {
+      if (attributes) {
+        if (!attributes[DEVWORKSPACE_STORAGE_TYPE_ATTR]) {
           patch.push({ op: 'add', path: devworkspaceStorageTypePath, value: currentPvcStrategy });
         }
       } else {
         patch.push({
           op: 'add',
           path: '/spec/template/attributes',
-          value: { 'controller.devfile.io/storage-type': currentPvcStrategy },
+          value: { [DEVWORKSPACE_STORAGE_TYPE_ATTR]: currentPvcStrategy },
         });
+        attributes = {};
       }
     }
 
-    if (patch.length > 0) {
-      await DwApi.patchWorkspace(workspace.metadata.namespace, workspace.metadata.name, patch);
-      await delay(800);
+    const openVSXURL = config.pluginRegistry.openVSXURL;
+    const components = cloneDeep(workspace.spec.template.components);
+    if (components) {
+      let shouldUpdate = false;
+      components.forEach(component => {
+        const envs = component.container?.env || [];
+        envs.forEach(env => {
+          if (env.name === this.openVSXUrlEnvName && env.value !== openVSXURL) {
+            shouldUpdate = true;
+            env.value = openVSXURL;
+          }
+        });
+      });
+      if (shouldUpdate) {
+        patch.push({ op: 'replace', path: '/spec/template/components', value: components });
+      }
     }
+
+    if (patch.length === 0) {
+      return workspace;
+    }
+    return DwApi.patchWorkspace(workspace.metadata.namespace, workspace.metadata.name, patch);
   }
 
-  async updateDebugMode(
+  async manageDebugMode(
     workspace: devfileApi.DevWorkspace,
     debugMode: boolean,
   ): Promise<devfileApi.DevWorkspace> {
     const patch: api.IPatch[] = [];
     const currentDebugMode = this.getDebugMode(workspace);
-
-    if (currentDebugMode === debugMode) {
-      return workspace;
-    }
-
-    const path = `/metadata/annotations/${this.escape(DEVWORKSPACE_DEBUG_START_ANNOTATION)}`;
-    if (!debugMode) {
-      patch.push({ op: 'remove', path });
-    } else {
-      if (workspace.metadata.annotations?.[DEVWORKSPACE_DEBUG_START_ANNOTATION]) {
-        patch.push({ op: 'replace', path, value: 'true' });
+    if (currentDebugMode !== debugMode) {
+      const path = `/metadata/annotations/${this.escape(DEVWORKSPACE_DEBUG_START_ANNOTATION)}`;
+      if (!debugMode) {
+        patch.push({ op: 'remove', path });
       } else {
-        patch.push({ op: 'add', path, value: 'true' });
+        if (workspace.metadata.annotations?.[DEVWORKSPACE_DEBUG_START_ANNOTATION]) {
+          patch.push({ op: 'replace', path, value: 'true' });
+        } else {
+          patch.push({ op: 'add', path, value: 'true' });
+        }
       }
     }
 
-    return await DwApi.patchWorkspace(workspace.metadata.namespace, workspace.metadata.name, patch);
+    if (patch.length === 0) {
+      return workspace;
+    }
+    return DwApi.patchWorkspace(workspace.metadata.namespace, workspace.metadata.name, patch);
+  }
+
+  /**
+   * Injects or removes the container build attribute depending on the CR `disableContainerBuildCapabilities` field value.
+   */
+  async manageContainerBuildAttribute(
+    workspace: devfileApi.DevWorkspace,
+    config: api.IServerConfig,
+  ): Promise<devfileApi.DevWorkspace> {
+    const patch: api.IPatch[] = [];
+    if (config.containerBuild.disableContainerBuildCapabilities) {
+      if (workspace.spec.template.attributes?.[DEVWORKSPACE_CONTAINER_BUILD_ATTR]) {
+        // remove the attribute
+        const path = `/spec/template/attributes/${this.escape(DEVWORKSPACE_CONTAINER_BUILD_ATTR)}`;
+        patch.push({ op: 'remove', path });
+      }
+    } else if (
+      !config.containerBuild.containerBuildConfiguration?.openShiftSecurityContextConstraint
+    ) {
+      console.warn(
+        'Skip injecting the container build attribute: "openShiftSecurityContextConstraint" is undefined',
+      );
+    } else {
+      // add the attribute
+      if (!workspace.spec.template.attributes) {
+        const path = '/spec/template/attributes';
+        const value = {
+          [DEVWORKSPACE_CONTAINER_BUILD_ATTR]:
+            config.containerBuild.containerBuildConfiguration.openShiftSecurityContextConstraint,
+        };
+        patch.push({ op: 'add', path, value });
+      } else {
+        const path = `/spec/template/attributes/${this.escape(DEVWORKSPACE_CONTAINER_BUILD_ATTR)}`;
+        const value =
+          config.containerBuild.containerBuildConfiguration.openShiftSecurityContextConstraint;
+        patch.push({ op: 'add', path, value });
+      }
+    }
+
+    if (patch.length === 0) {
+      return workspace;
+    }
+    return DwApi.patchWorkspace(workspace.metadata.namespace, workspace.metadata.name, patch);
   }
 
   async changeWorkspaceStatus(
@@ -958,6 +1042,7 @@ export class DevWorkspaceClient extends WorkspaceClient {
     const phase = devworkspace.status?.phase;
     const status = isDevWorkspaceStatus(phase) ? phase : DevWorkspaceStatus.STARTING;
     const message = devworkspace.status?.message || '';
+    const started = devworkspace.spec.started;
 
     if (!this.previousItems.has(namespace)) {
       const defaultItem = new Map<string, IStatusUpdate>();
@@ -974,11 +1059,16 @@ export class DevWorkspaceClient extends WorkspaceClient {
       namespace,
       workspaceId: devworkspace.status?.devworkspaceId,
       mainUrl: devworkspace.status?.mainUrl,
+      started,
     };
 
     previousItem?.set(workspaceUID, statusUpdate);
 
-    if (status === prevStatusUpdate?.status && message === prevStatusUpdate?.message) {
+    if (
+      started === prevStatusUpdate?.started &&
+      status === prevStatusUpdate?.status &&
+      message === prevStatusUpdate?.message
+    ) {
       return undefined;
     }
 
@@ -1003,8 +1093,9 @@ export class DevWorkspaceClient extends WorkspaceClient {
   async checkForTemplatesUpdate(
     namespace: string,
     pluginsByUrl: { [url: string]: devfileApi.Devfile } = {},
-    pluginRegistryUrl = '',
-    pluginRegistryInternalUrl = '',
+    pluginRegistryUrl: string | undefined,
+    pluginRegistryInternalUrl: string | undefined,
+    openVSXUrl: string | undefined,
   ): Promise<{ [templateName: string]: api.IPatch[] }> {
     const templates = await DwtApi.getTemplates(namespace);
     const managedTemplates = templates.filter(
@@ -1040,6 +1131,7 @@ export class DevWorkspaceClient extends WorkspaceClient {
               spec.components,
               pluginRegistryUrl,
               pluginRegistryInternalUrl,
+              openVSXUrl,
             );
           } else {
             spec[key] = plugin[key];
