@@ -25,6 +25,9 @@ import { convertDevfileV1toDevfileV2 } from '../../services/devfile/converters';
 import normalizeDevfileV2 from './normalizeDevfileV2';
 import normalizeDevfileV1 from './normalizeDevfileV1';
 import { selectDefaultNamespace } from '../InfrastructureNamespaces/selectors';
+import { getYamlResolver } from '../../services/dashboard-backend-client/yamlResolverApi';
+import { DEFAULT_REGISTRY } from '../DevfileRegistries';
+import { isOAuthResponse } from '../../services/oauth';
 
 const WorkspaceClient = container.get(CheWorkspaceClient);
 
@@ -35,18 +38,9 @@ export type OAuthResponse = {
     oauth_authentication_url: string;
   };
   errorCode: number;
-  message: string;
+  message: string | undefined;
 };
 
-export function isOAuthResponse(responseData: any): responseData is OAuthResponse {
-  if (
-    responseData?.attributes?.oauth_provider &&
-    responseData?.attributes?.oauth_authentication_url
-  ) {
-    return true;
-  }
-  return false;
-}
 export interface ResolverState extends FactoryResolver {
   optionalFilesContent?: {
     [fileName: string]: string;
@@ -78,7 +72,7 @@ interface ReceiveFactoryResolverAction {
 
 interface ReceiveFactoryResolverErrorAction {
   type: 'RECEIVE_FACTORY_RESOLVER_ERROR';
-  error: string;
+  error: string | undefined;
 }
 
 export type KnownAction =
@@ -144,22 +138,28 @@ export const actionCreators: ActionCreators = {
       try {
         await WorkspaceClient.restApiClient.provisionKubernetesNamespace();
 
-        const data = await WorkspaceClient.restApiClient.getFactoryResolver<FactoryResolver>(
-          location,
-          overrideParams,
-        );
-        // now, grab content of optional files if they're there
-        const vscodeExtensionsJson = await grabLink(data.links, '.vscode/extensions.json');
-        if (vscodeExtensionsJson) {
-          optionalFilesContent['.vscode/extensions.json'] = vscodeExtensionsJson;
-        }
-        const cheTheiaPlugins = await grabLink(data.links, '.che/che-theia-plugins.yaml');
-        if (cheTheiaPlugins) {
-          optionalFilesContent['.che/che-theia-plugins.yaml'] = cheTheiaPlugins;
-        }
-        const cheEditor = await grabLink(data.links, '.che/che-editor.yaml');
-        if (cheEditor) {
-          optionalFilesContent['.che/che-editor.yaml'] = cheEditor;
+        let data: FactoryResolver;
+
+        if (location.includes(DEFAULT_REGISTRY) && location.endsWith('.yaml')) {
+          data = await getYamlResolver(namespace, location);
+        } else {
+          data = await WorkspaceClient.restApiClient.getFactoryResolver<FactoryResolver>(
+            location,
+            overrideParams,
+          );
+          // now, grab content of optional files if they're there
+          const vscodeExtensionsJson = await grabLink(data.links, '.vscode/extensions.json');
+          if (vscodeExtensionsJson) {
+            optionalFilesContent['.vscode/extensions.json'] = vscodeExtensionsJson;
+          }
+          const cheTheiaPlugins = await grabLink(data.links, '.che/che-theia-plugins.yaml');
+          if (cheTheiaPlugins) {
+            optionalFilesContent['.che/che-theia-plugins.yaml'] = cheTheiaPlugins;
+          }
+          const cheEditor = await grabLink(data.links, '.che/che-editor.yaml');
+          if (cheEditor) {
+            optionalFilesContent['.che/che-editor.yaml'] = cheEditor;
+          }
         }
         if (!data.devfile) {
           throw new Error('The specified link does not contain a valid Devfile.');
@@ -212,8 +212,7 @@ export const actionCreators: ActionCreators = {
             throw response.data;
           }
         }
-        const errorMessage =
-          'Failed to request factory resolver: ' + common.helpers.errors.getMessage(e);
+        const errorMessage = common.helpers.errors.getMessage(e);
         dispatch({
           type: 'RECEIVE_FACTORY_RESOLVER_ERROR',
           error: errorMessage,
