@@ -300,6 +300,7 @@ describe('dwPlugins store', () => {
     it('should create REQUEST_DW_DEFAULT_EDITOR and RECEIVE_DW_DEFAULT_EDITOR when fetching default plugins', async () => {
       const store = new FakeStoreBuilder()
         .withDwServerConfig({
+          containerBuild: {},
           defaults: {
             editor: 'eclipse/theia/next',
             components: [
@@ -318,6 +319,9 @@ describe('dwPlugins store', () => {
             ],
             pvcStrategy: 'per-workspace',
           },
+          pluginRegistry: {
+            openVSXURL: '',
+          },
           timeouts: {
             inactivityTimeout: -1,
             runTimeout: -1,
