@@ -10,12 +10,13 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
+import { api } from '@eclipse-che/common';
 import mockAxios from 'axios';
 import { MockStoreEnhanced } from 'redux-mock-store';
 import { ThunkDispatch } from 'redux-thunk';
-import { FakeStoreBuilder } from '../../__mocks__/storeBuilder';
-import * as dwServerConfigStore from '../../ServerConfig';
 import { AppState } from '../..';
+import * as dwServerConfigStore from '../../ServerConfig';
+import { FakeStoreBuilder } from '../../__mocks__/storeBuilder';
 
 // mute the outputs
 console.error = jest.fn();
@@ -26,33 +27,44 @@ describe('dwPlugins store', () => {
   });
 
   describe('actions', () => {
+    const serverConfig: api.IServerConfig = {
+      containerBuild: {
+        disableContainerBuildCapabilities: false,
+        containerBuildConfiguration: {
+          openShiftSecurityContextConstraint: 'container-build',
+        },
+      },
+      defaults: {
+        editor: 'eclipse/theia/next',
+        components: [
+          {
+            name: 'universal-developer-image',
+            container: {
+              image: 'quay.io/devfile/universal-developer-image:ubi8-latest',
+            },
+          },
+        ],
+        plugins: [
+          {
+            editor: 'eclipse/theia/next',
+            plugins: ['https://test.com/devfile.yaml'],
+          },
+        ],
+        pvcStrategy: 'per-workspace',
+      },
+      pluginRegistry: {
+        openVSXURL: '',
+      },
+      timeouts: {
+        inactivityTimeout: -1,
+        runTimeout: -1,
+      },
+      cheNamespace: 'eclipse-che',
+    };
+
     it('should create RECEIVE_DW_SERVER_CONFIG when fetching server config', async () => {
       (mockAxios.get as jest.Mock).mockResolvedValueOnce({
-        data: {
-          defaults: {
-            editor: 'eclipse/theia/next',
-            components: [
-              {
-                name: 'universal-developer-image',
-                container: {
-                  image: 'quay.io/devfile/universal-developer-image:ubi8-latest',
-                },
-              },
-            ],
-            plugins: [
-              {
-                editor: 'eclipse/theia/next',
-                plugins: ['https://test.com/devfile.yaml'],
-              },
-            ],
-            pvcStrategy: 'per-workspace',
-          },
-          timeouts: {
-            inactivityTimeout: -1,
-            runTimeout: -1,
-          },
-          cheNamespace: 'eclipse-che',
-        },
+        data: serverConfig,
       });
 
       const store = new FakeStoreBuilder().build() as MockStoreEnhanced<
@@ -70,31 +82,7 @@ describe('dwPlugins store', () => {
         },
         {
           type: 'RECEIVE_DW_SERVER_CONFIG',
-          config: {
-            defaults: {
-              editor: 'eclipse/theia/next',
-              components: [
-                {
-                  name: 'universal-developer-image',
-                  container: {
-                    image: 'quay.io/devfile/universal-developer-image:ubi8-latest',
-                  },
-                },
-              ],
-              plugins: [
-                {
-                  editor: 'eclipse/theia/next',
-                  plugins: ['https://test.com/devfile.yaml'],
-                },
-              ],
-              pvcStrategy: 'per-workspace',
-            },
-            timeouts: {
-              inactivityTimeout: -1,
-              runTimeout: -1,
-            },
-            cheNamespace: 'eclipse-che',
-          },
+          config: serverConfig,
         },
       ];
       expect(actions).toEqual(expectedActions);
@@ -123,7 +111,7 @@ describe('dwPlugins store', () => {
       },
       {
         type: 'RECEIVE_DW_SERVER_CONFIG_ERROR',
-        error: 'Failed to fetch default plugins. Test error',
+        error: 'Test error',
       },
     ];
     expect(actions).toEqual(expectedActions);
