@@ -26,8 +26,14 @@ export const selectDefaultPlugins = createSelector(
   state => state.config.defaults?.plugins || [],
 );
 
+export const selectOpenVSXUrl = createSelector(
+  selectState,
+  state => state.config.pluginRegistry.openVSXURL,
+);
+
 export const selectPvcStrategy = createSelector(
   selectState,
-  state => (state.config.defaults.pvcStrategy || 'per-workspace') as che.WorkspaceStorageType,
+  state => (state.config.defaults.pvcStrategy || '') as che.WorkspaceStorageType,
 );
+
 export const selectServerConfigError = createSelector(selectState, state => state.error);
