@@ -10,36 +10,38 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
+import common from '@eclipse-che/common';
+import { cloneDeep } from 'lodash';
 import { Action, Reducer } from 'redux';
 import { ThunkDispatch } from 'redux-thunk';
-import common from '@eclipse-che/common';
 import { AppState, AppThunk } from '../..';
 import { container } from '../../../inversify.config';
+import { injectKubeConfig } from '../../../services/dashboard-backend-client/devWorkspaceApi';
+import devfileApi, { isDevWorkspace } from '../../../services/devfileApi';
+import { devWorkspaceKind } from '../../../services/devfileApi/devWorkspace';
+import {
+  DEVWORKSPACE_CHE_EDITOR,
+  DEVWORKSPACE_UPDATING_TIMESTAMP_ANNOTATION,
+} from '../../../services/devfileApi/devWorkspace/metadata';
+import { getDefer, IDeferred } from '../../../services/helpers/deferred';
+import { delay } from '../../../services/helpers/delay';
+import { DisposableCollection } from '../../../services/helpers/disposable';
 import { DevWorkspaceStatus, WorkspacesLogs } from '../../../services/helpers/types';
-import { createObject } from '../../helpers';
+import { WorkspaceAdapter } from '../../../services/workspace-adapter';
 import {
   DevWorkspaceClient,
   DEVWORKSPACE_NEXT_START_ANNOTATION,
   IStatusUpdate,
 } from '../../../services/workspace-client/devworkspace/devWorkspaceClient';
-import devfileApi, { isDevWorkspace } from '../../../services/devfileApi';
-import { deleteLogs, mergeLogs } from '../logs';
-import { getDefer, IDeferred } from '../../../services/helpers/deferred';
-import { DisposableCollection } from '../../../services/helpers/disposable';
-import { selectDwEditorsPluginsList } from '../../Plugins/devWorkspacePlugins/selectors';
-import { devWorkspaceKind } from '../../../services/devfileApi/devWorkspace';
-import { WorkspaceAdapter } from '../../../services/workspace-adapter';
-import {
-  DEVWORKSPACE_CHE_EDITOR,
-  DEVWORKSPACE_UPDATING_TIMESTAMP_ANNOTATION,
-} from '../../../services/devfileApi/devWorkspace/metadata';
-import * as DwPluginsStore from '../../Plugins/devWorkspacePlugins';
-import { selectDefaultNamespace } from '../../InfrastructureNamespaces/selectors';
-import { injectKubeConfig } from '../../../services/dashboard-backend-client/devWorkspaceApi';
 import { selectRunningWorkspacesLimit } from '../../ClusterConfig/selectors';
-import { cloneDeep } from 'lodash';
-import { delay } from '../../../services/helpers/delay';
+import { createObject } from '../../helpers';
+import { selectDefaultNamespace } from '../../InfrastructureNamespaces/selectors';
+import * as DwPluginsStore from '../../Plugins/devWorkspacePlugins';
+import { selectDwEditorsPluginsList } from '../../Plugins/devWorkspacePlugins/selectors';
 import * as DwServerConfigStore from '../../ServerConfig';
+import { selectOpenVSXUrl } from '../../ServerConfig/selectors';
+import { deleteLogs, mergeLogs } from '../logs';
+import { selectRunningDevWorkspacesLimitExceeded } from './selectors';
 
 const devWorkspaceClient = container.get(DevWorkspaceClient);
 
@@ -54,6 +56,13 @@ export interface State {
   workspacesLogs: WorkspacesLogs;
 }
 
+export class RunningWorkspacesExceededError extends Error {
+  constructor(message: string) {
+    super(message);
+    this.name = 'RunningWorkspacesExceededError';
+  }
+}
+
 interface RequestDevWorkspacesAction extends Action {
   type: 'REQUEST_DEVWORKSPACE';
 }
@@ -80,6 +89,7 @@ interface UpdateWorkspaceStatusAction extends Action {
   status: string;
   message: string;
   mainUrl?: string;
+  started: boolean;
 }
 
 interface UpdateWorkspacesLogsAction extends Action {
@@ -210,9 +220,12 @@ export const actionCreators: ActionCreators = {
       try {
         const defaultKubernetesNamespace = selectDefaultNamespace(getState());
         const defaultNamespace = defaultKubernetesNamespace.name;
-        const { workspaces, resourceVersion } = await devWorkspaceClient.getAllWorkspaces(
-          defaultNamespace,
-        );
+        const { workspaces, resourceVersion } = defaultNamespace
+          ? await devWorkspaceClient.getAllWorkspaces(defaultNamespace)
+          : {
+              workspaces: [],
+              resourceVersion: '',
+            };
 
         dispatch({
           type: 'RECEIVE_DEVWORKSPACE',
@@ -276,32 +289,24 @@ export const actionCreators: ActionCreators = {
 
   startWorkspace:
     (
-      workspace: devfileApi.DevWorkspace,
+      _workspace: devfileApi.DevWorkspace,
       debugWorkspace = false,
     ): AppThunk<KnownAction, Promise<void>> =>
     async (dispatch, getState): Promise<void> => {
+      let workspace = getState().devWorkspaces.workspaces.find(
+        w => w.metadata.uid === _workspace.metadata.uid,
+      );
+      if (workspace === undefined) {
+        console.warn(`Can't find the target workspace ${_workspace.metadata.name}`);
+        return;
+      }
+      if (workspace.spec.started) {
+        console.warn(`Workspace ${_workspace.metadata.name} already started`);
+        return;
+      }
       dispatch({ type: 'REQUEST_DEVWORKSPACE' });
-      // await delay(500);
-      // throw new Error('asdfjkl;');
       try {
-        const { workspaces } = await devWorkspaceClient.getAllWorkspaces(
-          workspace.metadata.namespace,
-        );
-        const runningWorkspaces = workspaces.filter(w => w.spec.started === true);
-        const runningLimit = selectRunningWorkspacesLimit(getState());
-        if (runningWorkspaces.length >= runningLimit) {
-          throw new Error('You are not allowed to start more workspaces.');
-        }
-        await devWorkspaceClient.updateDebugMode(workspace, debugWorkspace);
-        await dispatch(DwServerConfigStore.actionCreators.requestServerConfig());
-        const config = getState().dwServerConfig.config;
-        await devWorkspaceClient.updateConfigData(workspace, config);
-        let updatedWorkspace: devfileApi.DevWorkspace;
-        const workspaceUID = workspace.metadata.uid;
-        dispatch({
-          type: 'DELETE_DEVWORKSPACE_LOGS',
-          workspaceUID,
-        });
+        checkRunningWorkspacesLimit(getState());
 
         if (workspace.metadata.annotations?.[DEVWORKSPACE_NEXT_START_ANNOTATION]) {
           const storedDevWorkspace = JSON.parse(
@@ -319,20 +324,38 @@ export const actionCreators: ActionCreators = {
 
           delete workspace.metadata.annotations[DEVWORKSPACE_NEXT_START_ANNOTATION];
           workspace.spec.template = storedDevWorkspace.spec.template;
-          workspace.spec.started = true;
-          updatedWorkspace = await devWorkspaceClient.update(workspace);
-        } else {
-          updatedWorkspace = await devWorkspaceClient.changeWorkspaceStatus(workspace, true, true);
+          workspace.spec.started = false;
+          workspace = await devWorkspaceClient.update(workspace);
         }
 
-        const editor = updatedWorkspace.metadata.annotations
-          ? updatedWorkspace.metadata.annotations[DEVWORKSPACE_CHE_EDITOR]
+        await dispatch(DwServerConfigStore.actionCreators.requestServerConfig());
+        const config = getState().dwServerConfig.config;
+        workspace = await devWorkspaceClient.managePvcStrategy(workspace, config);
+
+        // inject or remove the container build attribute
+        workspace = await devWorkspaceClient.manageContainerBuildAttribute(workspace, config);
+
+        workspace = await devWorkspaceClient.manageDebugMode(workspace, debugWorkspace);
+
+        const workspaceUID = workspace.metadata.uid;
+        dispatch({
+          type: 'DELETE_DEVWORKSPACE_LOGS',
+          workspaceUID,
+        });
+
+        const startingWorkspace = await devWorkspaceClient.changeWorkspaceStatus(
+          workspace,
+          true,
+          true,
+        );
+        const editor = startingWorkspace.metadata.annotations
+          ? startingWorkspace.metadata.annotations[DEVWORKSPACE_CHE_EDITOR]
           : undefined;
         const defaultPlugins = getState().dwPlugins.defaultPlugins;
-        await devWorkspaceClient.onStart(updatedWorkspace, defaultPlugins, editor);
+        await devWorkspaceClient.onStart(startingWorkspace, defaultPlugins, editor);
         dispatch({
           type: 'UPDATE_DEVWORKSPACE',
-          workspace: updatedWorkspace,
+          workspace: startingWorkspace,
         });
 
         // sometimes workspace don't have enough time to change its status.
@@ -352,7 +375,7 @@ export const actionCreators: ActionCreators = {
         await Promise.race([defer.promise, delay(startingTimeout)]);
         toDispose.dispose();
 
-        devWorkspaceClient.checkForDevWorkspaceError(updatedWorkspace);
+        devWorkspaceClient.checkForDevWorkspaceError(startingWorkspace);
       } catch (e) {
         const errorMessage =
           `Failed to start the workspace ${workspace.metadata.name}, reason: ` +
@@ -361,7 +384,11 @@ export const actionCreators: ActionCreators = {
           type: 'RECEIVE_DEVWORKSPACE_ERROR',
           error: errorMessage,
         });
-        throw errorMessage;
+
+        if (common.helpers.errors.isError(e)) {
+          throw e;
+        }
+        throw new Error(errorMessage);
       }
     },
 
@@ -511,6 +538,7 @@ export const actionCreators: ActionCreators = {
     async (dispatch, getState): Promise<void> => {
       const state = getState();
       const defaultKubernetesNamespace = selectDefaultNamespace(state);
+      const openVSXUrl = selectOpenVSXUrl(state);
       const defaultNamespace = defaultKubernetesNamespace.name;
       try {
         const cheEditor = editorId ? editorId : state.dwPlugins.defaultEditorName;
@@ -525,6 +553,7 @@ export const actionCreators: ActionCreators = {
           cheEditor,
           pluginRegistryUrl,
           pluginRegistryInternalUrl,
+          openVSXUrl,
         );
 
         if (workspace.spec.started) {
@@ -594,6 +623,7 @@ export const actionCreators: ActionCreators = {
         // If the devworkspace doesn't have a namespace then we assign it to the default kubernetesNamespace
         const devWorkspaceDevfile = devfile as devfileApi.Devfile;
         const defaultNamespace = selectDefaultNamespace(state);
+        const openVSXURL = selectOpenVSXUrl(state);
         const dwEditorsList = selectDwEditorsPluginsList(cheEditor)(state);
         const workspace = await devWorkspaceClient.createFromDevfile(
           devWorkspaceDevfile,
@@ -601,6 +631,7 @@ export const actionCreators: ActionCreators = {
           dwEditorsList,
           pluginRegistryUrl,
           pluginRegistryInternalUrl,
+          openVSXURL,
           cheEditor,
           optionalFilesContent,
         );
@@ -613,9 +644,7 @@ export const actionCreators: ActionCreators = {
           workspace,
         });
       } catch (e) {
-        const errorMessage =
-          'Failed to create a new workspace from the devfile, reason: ' +
-          common.helpers.errors.getMessage(e);
+        const errorMessage = common.helpers.errors.getMessage(e);
         dispatch({
           type: 'RECEIVE_DEVWORKSPACE_ERROR',
           error: errorMessage,
@@ -682,6 +711,7 @@ export const reducer: Reducer<State> = (state: State | undefined, action: KnownA
           nextWorkspace.status.phase = action.status;
           nextWorkspace.status.message = action.message;
           nextWorkspace.status.mainUrl = action.mainUrl;
+          nextWorkspace.spec.started = action.started;
           return nextWorkspace;
         }),
       });
@@ -730,16 +760,33 @@ export const reducer: Reducer<State> = (state: State | undefined, action: KnownA
   }
 };
 
+export function checkRunningWorkspacesLimit(state: AppState) {
+  const runningLimitExceeded = selectRunningDevWorkspacesLimitExceeded(state);
+  if (runningLimitExceeded === false) {
+    return;
+  }
+
+  const runningLimit = selectRunningWorkspacesLimit(state);
+  throwRunningWorkspacesExceededError(runningLimit);
+}
+
+export function throwRunningWorkspacesExceededError(runningLimit: number): never {
+  const message = `You can only have ${runningLimit} running workspace${
+    runningLimit > 1 ? 's' : ''
+  } at a time.`;
+  throw new RunningWorkspacesExceededError(message);
+}
+
 async function onStatusUpdateReceived(
   dispatch: ThunkDispatch<AppState, unknown, KnownAction>,
   statusUpdate: IStatusUpdate,
 ) {
-  const { status, message, prevStatus, workspaceUID, namespace, workspaceId, mainUrl } =
+  const { status, message, prevStatus, workspaceUID, namespace, workspaceId, mainUrl, started } =
     statusUpdate;
 
   if (status !== prevStatus) {
     const type = 'UPDATE_DEVWORKSPACE_STATUS';
-    dispatch({ type, workspaceUID, message, status, mainUrl });
+    dispatch({ type, workspaceUID, message, status, mainUrl, started });
 
     const onChangeCallback = onStatusChangeCallbacks.get(workspaceUID);
     if (onChangeCallback) {
